@@ -12,6 +12,8 @@ from werkzeug.security import generate_password_hash
 from uuid import uuid4
 
 DEBUG = True
+CODEMIRROR_LANGUAGES = [u'markdown']
+CODEMIRROR_THEME = u'xq-light'
 PERMANENT_SESSION_LIFETIME = 2678400
 LANGUAGE = u'en'
 SITENAME = u'Microbe Default site'
